@@ -1,11 +1,7 @@
 package App::FileMoveUtils;
 
-use strict;
-
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-27'; # DATE
-our $DIST = 'App-FileRenameUtils'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $DATE = '2020-05-30'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Utilities related to renaming/moving files
@@ -22,7 +18,7 @@ App::FileMoveUtils - Utilities related to renaming/moving files
 
 =head1 VERSION
 
-This document describes version 0.007 of App::FileMoveUtils (from Perl distribution App-FileRenameUtils), released on 2023-02-27.
+This document describes version 0.003 of App::FileMoveUtils (from Perl distribution App-FileRenameUtils), released on 2020-05-30.
 
 =head1 DESCRIPTION
 
@@ -36,35 +32,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-FileRe
 
 Source repository is at L<https://github.com/perlancar/perl-App-FileRenameUtils>.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 CONTRIBUTING
-
-
-To contribute, you can send patches by email/via RT, or send pull requests on
-GitHub.
-
-Most of the time, you don't need to build the distribution yourself. You can
-simply modify the code, then test via:
-
- % prove -l
-
-If you want to build the distribution (e.g. to try to install it locally on your
-system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
-L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
-that are considered a bug and can be reported to me.
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023, 2020, 2019 by perlancar <perlancar@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-FileRenameUtils>
@@ -73,4 +40,15 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
